import java.awt.Rectangle;

import javax.swing.JLabel;
import javax.swing.JTextPane;
import javax.swing.SwingUtilities;
import javax.swing.event.CaretEvent;
import javax.swing.event.CaretListener;
import javax.swing.text.BadLocationException;

@SuppressWarnings("serial")
public class CaretListenerLabel extends JLabel implements CaretListener{
	JTextPane editor =null;
	
	public CaretListenerLabel(JTextPane editor, String label) {
        super(label);
        this.editor = editor;
    }

    //Might not be invoked from the event dispatch thread.
    public void caretUpdate(CaretEvent e) {
        displaySelectionInfo(e.getDot(), e.getMark());
    }

    //This method can be invoked from any thread.  It 
    //invokes the setText and modelToView methods, which 
    //must run on the event dispatch thread. We use
    //invokeLater to schedule the code for execution
    //on the event dispatch thread.
    protected void displaySelectionInfo(final int dot,
                                        final int mark) {
        SwingUtilities.invokeLater(new Runnable() {
            public void run() {
                if (dot == mark) {  // no selection
                    try {
                        Rectangle caretCoords = editor.modelToView(dot);
                        //Convert it to view coordinates.
                        setText("caret: text position: " + dot
                        		//  + ", view location = ["
                             //   + caretCoords.x + ", "
                                //   + caretCoords.y + "]"
                                + "\n");
                    } catch (BadLocationException ble) {
                        setText("caret: text position: " + dot + "\n");
                    }
                } else if (dot < mark) {
                    setText("selection from: " + dot
                            + " to " + mark + "\n");
                } else {
                    setText("selection from: " + mark
                            + " to " + dot + "\n");
                }
            }
        });
    }
}
